# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.get_role_by_name200_response_pagination import GetRoleByName200ResponsePagination  # noqa: E501
from onelogin.rest import ApiException

class TestGetRoleByName200ResponsePagination(unittest.TestCase):
    """GetRoleByName200ResponsePagination unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GetRoleByName200ResponsePagination
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetRoleByName200ResponsePagination`
        """
        model = onelogin.models.get_role_by_name200_response_pagination.GetRoleByName200ResponsePagination()  # noqa: E501
        if include_optional :
            return GetRoleByName200ResponsePagination(
                after_cursor = 'xWNjb3VudF9pZDo6OjUzNDEzLS0jI2lkOjo6OTA0MjU3NTQ2', 
                before_cursor = '""', 
                next_link = 'https://{subdomain}.onelogin.com/api/1/events?after_cursor=xWNjb3VudF9pZDo6OjUzNDEzLS0jI2lkOjo6OTA0MjU3NTQ2', 
                previous_link = '""'
            )
        else :
            return GetRoleByName200ResponsePagination(
        )
        """

    def testGetRoleByName200ResponsePagination(self):
        """Test GetRoleByName200ResponsePagination"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from onelogin.models.activate_mfa_factors_request import ActivateMfaFactorsRequest
from onelogin.models.add_client_app201_response import AddClientApp201Response
from onelogin.models.add_client_app_request import AddClientAppRequest
from onelogin.models.add_privilege_to_role201_response import AddPrivilegeToRole201Response
from onelogin.models.add_privilege_to_role_request import AddPrivilegeToRoleRequest
from onelogin.models.add_roles_to_user_request import AddRolesToUserRequest
from onelogin.models.assign_users_to_privilege_request import AssignUsersToPrivilegeRequest
from onelogin.models.create_app_request import CreateAppRequest
from onelogin.models.create_app_request_one_of import CreateAppRequestOneOf
from onelogin.models.create_app_request_one_of1 import CreateAppRequestOneOf1
from onelogin.models.create_app_request_one_of1_configuration import CreateAppRequestOneOf1Configuration
from onelogin.models.create_app_request_one_of1_parameters import CreateAppRequestOneOf1Parameters
from onelogin.models.create_app_request_one_of1_parameters_saml_username import CreateAppRequestOneOf1ParametersSamlUsername
from onelogin.models.create_app_request_one_of_configuration import CreateAppRequestOneOfConfiguration
from onelogin.models.create_auth_claim_request import CreateAuthClaimRequest
from onelogin.models.create_brand201_response import CreateBrand201Response
from onelogin.models.create_brand201_response_background import CreateBrand201ResponseBackground
from onelogin.models.create_brand201_response_background_urls import CreateBrand201ResponseBackgroundUrls
from onelogin.models.create_brand201_response_logo import CreateBrand201ResponseLogo
from onelogin.models.create_brand201_response_logo_urls import CreateBrand201ResponseLogoUrls
from onelogin.models.create_brand_request import CreateBrandRequest
from onelogin.models.create_device_verification201_response import CreateDeviceVerification201Response
from onelogin.models.create_device_verification_request import CreateDeviceVerificationRequest
from onelogin.models.create_factor_registration201_response import CreateFactorRegistration201Response
from onelogin.models.create_factor_registration_request import CreateFactorRegistrationRequest
from onelogin.models.create_message_template_request import CreateMessageTemplateRequest
from onelogin.models.create_message_template_request_template import CreateMessageTemplateRequestTemplate
from onelogin.models.create_message_template_request_template_one_of import CreateMessageTemplateRequestTemplateOneOf
from onelogin.models.create_message_template_request_template_one_of1 import CreateMessageTemplateRequestTemplateOneOf1
from onelogin.models.create_message_template_request_template_one_of1_all_of import CreateMessageTemplateRequestTemplateOneOf1AllOf
from onelogin.models.create_message_template_request_template_one_of_all_of import CreateMessageTemplateRequestTemplateOneOfAllOf
from onelogin.models.create_privilege200_response import CreatePrivilege200Response
from onelogin.models.create_roles201_response_inner import CreateRoles201ResponseInner
from onelogin.models.create_scope200_response import CreateScope200Response
from onelogin.models.create_scope_request import CreateScopeRequest
from onelogin.models.enroll_mfa_factor200_response import EnrollMfaFactor200Response
from onelogin.models.enroll_mfa_factor_request import EnrollMfaFactorRequest
from onelogin.models.generate_mf_atoken200_response import GenerateMFAtoken200Response
from onelogin.models.generate_mf_atoken_request import GenerateMFAtokenRequest
from onelogin.models.generate_otp201_response import GenerateOTP201Response
from onelogin.models.generate_otp_request import GenerateOTPRequest
from onelogin.models.generate_saml_assert200_response import GenerateSamlAssert200Response
from onelogin.models.generate_saml_assert_request import GenerateSamlAssertRequest
from onelogin.models.generate_token200_response import GenerateToken200Response
from onelogin.models.generate_token400_response import GenerateToken400Response
from onelogin.models.generate_token_request import GenerateTokenRequest
from onelogin.models.get_assigned_user200_response import GetAssignedUser200Response
from onelogin.models.get_auth_factors200_response import GetAuthFactors200Response
from onelogin.models.get_authclaims200_response_inner import GetAuthclaims200ResponseInner
from onelogin.models.get_authentication_devices200_response_inner import GetAuthenticationDevices200ResponseInner
from onelogin.models.get_brand_apps200_response_inner import GetBrandApps200ResponseInner
from onelogin.models.get_custom_attributes200_response import GetCustomAttributes200Response
from onelogin.models.get_email_settings200_response import GetEmailSettings200Response
from onelogin.models.get_email_settings200_response_one_of import GetEmailSettings200ResponseOneOf
from onelogin.models.get_email_settings200_response_one_of1 import GetEmailSettings200ResponseOneOf1
from onelogin.models.get_enrolled_factors200_response import GetEnrolledFactors200Response
from onelogin.models.get_enrolled_factors200_response_data import GetEnrolledFactors200ResponseData
from onelogin.models.get_enrolled_factors200_response_data_otp_devices_inner import GetEnrolledFactors200ResponseDataOtpDevicesInner
from onelogin.models.get_event_by_id200_response import GetEventById200Response
from onelogin.models.get_event_by_id200_response_status import GetEventById200ResponseStatus
from onelogin.models.get_event_types200_response import GetEventTypes200Response
from onelogin.models.get_event_types200_response_data_inner import GetEventTypes200ResponseDataInner
from onelogin.models.get_events200_response import GetEvents200Response
from onelogin.models.get_events200_response_data_inner import GetEvents200ResponseDataInner
from onelogin.models.get_events200_response_pagination import GetEvents200ResponsePagination
from onelogin.models.get_groups200_response import GetGroups200Response
from onelogin.models.get_groups200_response_data_inner import GetGroups200ResponseDataInner
from onelogin.models.get_invite_link200_response import GetInviteLink200Response
from onelogin.models.get_invite_link_request import GetInviteLinkRequest
from onelogin.models.get_mfa_factors200_response import GetMFAFactors200Response
from onelogin.models.get_mfa_factors200_response_data import GetMFAFactors200ResponseData
from onelogin.models.get_mfa_factors200_response_data_auth_factors_inner import GetMFAFactors200ResponseDataAuthFactorsInner
from onelogin.models.get_rate_limit200_response import GetRateLimit200Response
from onelogin.models.get_rate_limit200_response_data import GetRateLimit200ResponseData
from onelogin.models.get_risk_score200_response import GetRiskScore200Response
from onelogin.models.get_risk_score_request import GetRiskScoreRequest
from onelogin.models.get_risk_scores200_response import GetRiskScores200Response
from onelogin.models.get_risk_scores200_response_scores import GetRiskScores200ResponseScores
from onelogin.models.get_role_apps200_response_inner import GetRoleApps200ResponseInner
from onelogin.models.get_role_by_id200_response import GetRoleById200Response
from onelogin.models.get_role_by_id200_response_data_inner import GetRoleById200ResponseDataInner
from onelogin.models.get_role_by_name200_response import GetRoleByName200Response
from onelogin.models.get_role_by_name200_response_data_inner import GetRoleByName200ResponseDataInner
from onelogin.models.get_role_by_name200_response_pagination import GetRoleByName200ResponsePagination
from onelogin.models.get_scopes200_response_inner import GetScopes200ResponseInner
from onelogin.models.get_scopes200_response_inner_configuration import GetScopes200ResponseInnerConfiguration
from onelogin.models.get_scopes401_response import GetScopes401Response
from onelogin.models.get_user_apps200_response_inner import GetUserApps200ResponseInner
from onelogin.models.get_user_roles200_response import GetUserRoles200Response
from onelogin.models.get_user_verification200_response import GetUserVerification200Response
from onelogin.models.list_actions200_response_inner import ListActions200ResponseInner
from onelogin.models.list_app_rules200_response_inner import ListAppRules200ResponseInner
from onelogin.models.list_apps200_response import ListApps200Response
from onelogin.models.list_apps200_response_provisioning import ListApps200ResponseProvisioning
from onelogin.models.list_brands200_response_inner import ListBrands200ResponseInner
from onelogin.models.list_client_apps200_response import ListClientApps200Response
from onelogin.models.list_client_apps200_response_scopes_inner import ListClientApps200ResponseScopesInner
from onelogin.models.list_condition_operators200_response_inner import ListConditionOperators200ResponseInner
from onelogin.models.list_conditions200_response_inner import ListConditions200ResponseInner
from onelogin.models.list_connectors200_response import ListConnectors200Response
from onelogin.models.list_mapping_action_values200_response_inner import ListMappingActionValues200ResponseInner
from onelogin.models.list_mapping_conditions200_response import ListMappingConditions200Response
from onelogin.models.list_mapping_conditions_operators200_response_inner import ListMappingConditionsOperators200ResponseInner
from onelogin.models.list_mapping_contion_values200_response_inner import ListMappingContionValues200ResponseInner
from onelogin.models.list_mappings200_response_inner import ListMappings200ResponseInner
from onelogin.models.list_mappings200_response_inner_actions_inner import ListMappings200ResponseInnerActionsInner
from onelogin.models.list_mappings200_response_inner_conditions_inner import ListMappings200ResponseInnerConditionsInner
from onelogin.models.list_mappings_actions200_response_inner import ListMappingsActions200ResponseInner
from onelogin.models.list_message_templates200_response_inner import ListMessageTemplates200ResponseInner
from onelogin.models.list_privelege_roles200_response import ListPrivelegeRoles200Response
from onelogin.models.list_priveleges200_response_inner import ListPriveleges200ResponseInner
from onelogin.models.list_priveleges200_response_inner_privilege import ListPriveleges200ResponseInnerPrivilege
from onelogin.models.list_priveleges200_response_inner_privilege_statement_inner import ListPriveleges200ResponseInnerPrivilegeStatementInner
from onelogin.models.list_risk_rules200_response_inner import ListRiskRules200ResponseInner
from onelogin.models.list_risk_rules200_response_inner_source import ListRiskRules200ResponseInnerSource
from onelogin.models.list_roles200_response_inner import ListRoles200ResponseInner
from onelogin.models.list_users200_response_inner import ListUsers200ResponseInner
from onelogin.models.lock_account_user_request import LockAccountUserRequest
from onelogin.models.remove_role_users_request import RemoveRoleUsersRequest
from onelogin.models.remove_user_role_request import RemoveUserRoleRequest
from onelogin.models.remove_user_role_request_role_id_array_inner import RemoveUserRoleRequestRoleIdArrayInner
from onelogin.models.revoke_tokens_request import RevokeTokensRequest
from onelogin.models.send_invite_link200_response import SendInviteLink200Response
from onelogin.models.send_invite_link_request import SendInviteLinkRequest
from onelogin.models.set_user_state_request import SetUserStateRequest
from onelogin.models.track_risk_event_request import TrackRiskEventRequest
from onelogin.models.track_risk_event_request_device import TrackRiskEventRequestDevice
from onelogin.models.track_risk_event_request_session import TrackRiskEventRequestSession
from onelogin.models.track_risk_event_request_user import TrackRiskEventRequestUser
from onelogin.models.update_client_app_request import UpdateClientAppRequest
from onelogin.models.update_password_insecure_request import UpdatePasswordInsecureRequest
from onelogin.models.update_password_secure_request import UpdatePasswordSecureRequest
from onelogin.models.update_privilege200_response import UpdatePrivilege200Response
from onelogin.models.update_risk_rule_request import UpdateRiskRuleRequest
from onelogin.models.ver_factor_saml200_response import VerFactorSaml200Response
from onelogin.models.ver_factor_saml_request import VerFactorSamlRequest
from onelogin.models.verify_mfa_factor_request import VerifyMfaFactorRequest
from onelogin.models.verify_user_registration200_response import VerifyUserRegistration200Response
from onelogin.models.verify_user_registration_request import VerifyUserRegistrationRequest
from onelogin.models.verify_user_verification_request import VerifyUserVerificationRequest



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.create_message_template_request_template import CreateMessageTemplateRequestTemplate  # noqa: E501
from onelogin.rest import ApiException

class TestCreateMessageTemplateRequestTemplate(unittest.TestCase):
    """CreateMessageTemplateRequestTemplate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateMessageTemplateRequestTemplate
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateMessageTemplateRequestTemplate`
        """
        model = onelogin.models.create_message_template_request_template.CreateMessageTemplateRequestTemplate()  # noqa: E501
        if include_optional :
            return CreateMessageTemplateRequestTemplate(
                subject = 'Email MFA App Verification Code', 
                html = '<html><head></head><body><p>Here is the code: {{otp_code}}</p></body></html>', 
                plain = 'Here is the code: {{otp_code}}', 
                message = 'Here is the code: {{otp_code}}'
            )
        else :
            return CreateMessageTemplateRequestTemplate(
                subject = 'Email MFA App Verification Code',
                html = '<html><head></head><body><p>Here is the code: {{otp_code}}</p></body></html>',
                plain = 'Here is the code: {{otp_code}}',
                message = 'Here is the code: {{otp_code}}',
        )
        """

    def testCreateMessageTemplateRequestTemplate(self):
        """Test CreateMessageTemplateRequestTemplate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, validator

class GetEvents200ResponseDataInner(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    account_id: Optional[StrictInt] = Field(None, description="Account that triggered the event.")
    actor_system: Optional[StrictStr] = Field(None, description="Acting system that triggered the event when the actor is not a user.")
    actor_user_id: Optional[StrictInt] = Field(None, description="ID of the user whose action triggered the event.")
    actor_user_name: Optional[StrictStr] = Field(None, description="First and last name of the user whose action triggered the event.")
    adc_id: Optional[StrictInt] = None
    app_name: Optional[StrictStr] = Field(None, alias="app-name", description="Name of the app involved in the event, if applicable.")
    app_id: Optional[StrictInt] = Field(None, description="ID of the app involved in the event, if applicable.")
    assumed_by_superadmin_or_reseller: Optional[StrictInt] = None
    assuming_acting_user_id: Optional[StrictInt] = Field(None, description="ID of the user who assumed the role of the acting user to trigger the event, if applicable.")
    certificate_id: Optional[StrictInt] = None
    client_id: Optional[StrictStr] = Field(None, description="Client ID used to generate the access token that made the API call that generated the event.")
    created_at: Optional[StrictStr] = Field(None, description="ISO8601 Time and date at which the event was created. This value is autogenerated by OneLogin.")
    custom_message: Optional[StrictStr] = Field(None, description="More details about the event.")
    directory_sync_run_id: Optional[StrictInt] = Field(None, description="Directory sync run ID.")
    error_description: Optional[StrictStr] = Field(None, description="Provisioning error details, if applicable.")
    event_type_id: Optional[StrictInt] = Field(None, description="Type of event triggered.")
    group_name: Optional[StrictStr] = Field(None, alias="group-name", description="Name of a group involved in the event.")
    group_id: Optional[StrictInt] = Field(None, description="ID of a group involved in the event.")
    id: Optional[StrictInt] = Field(None, description="Event's unique ID in OneLogin. Autogenerated by OneLogin.")
    ipaddr: Optional[StrictStr] = Field(None, description="IP address of the machine used to trigger the event.")
    mapping_id: Optional[StrictInt] = None
    notes: Optional[StrictStr] = Field(None, description="More details about the event.")
    object_id: Optional[StrictInt] = None
    otp_device_id: Optional[StrictInt] = Field(None, description="ID of a device involved in the event.")
    otp_device_name: Optional[StrictStr] = Field(None, description="Name of a device involved in the event.")
    param: Optional[StrictStr] = None
    policy_id: Optional[StrictInt] = Field(None, description="ID of the policy involved in the event.")
    policy_name: Optional[StrictStr] = Field(None, description="Name of the policy involved in the event.")
    policy_type: Optional[StrictStr] = None
    privilege_id: Optional[StrictInt] = None
    proxy_ip: Optional[StrictStr] = None
    radius_config_id: Optional[StrictInt] = None
    resolved_at: Optional[StrictStr] = None
    resource_type_id: Optional[StrictInt] = Field(None, description="ID of the resource (user, role, group, and so forth) associated with the event.")
    risk_cookie_id: Optional[StrictStr] = Field(None, description="Identifier for risk cookie")
    risk_reasons: Optional[StrictStr] = None
    risk_score: Optional[StrictInt] = None
    role_id: Optional[StrictInt] = Field(None, description="ID of a role involved in the event.")
    role_name: Optional[StrictStr] = Field(None, description="Name of a role involved in the event.")
    service_directory_id: Optional[StrictInt] = None
    solved: Optional[StrictBool] = None
    trusted_idp_id: Optional[StrictInt] = None
    user_field_id: Optional[StrictInt] = None
    user_id: Optional[StrictInt] = Field(None, description="ID of the user that was acted upon to trigger the event.")
    user_name: Optional[StrictStr] = Field(None, description="Name of the user that was acted upon to trigger the event.")
    __properties = ["account_id", "actor_system", "actor_user_id", "actor_user_name", "adc_id", "app-name", "app_id", "assumed_by_superadmin_or_reseller", "assuming_acting_user_id", "certificate_id", "client_id", "created_at", "custom_message", "directory_sync_run_id", "error_description", "event_type_id", "group-name", "group_id", "id", "ipaddr", "mapping_id", "notes", "object_id", "otp_device_id", "otp_device_name", "param", "policy_id", "policy_name", "policy_type", "privilege_id", "proxy_ip", "radius_config_id", "resolved_at", "resource_type_id", "risk_cookie_id", "risk_reasons", "risk_score", "role_id", "role_name", "service_directory_id", "solved", "trusted_idp_id", "user_field_id", "user_id", "user_name"]

    @validator('event_type_id')
    def event_type_id_validate_enum(cls, v):
        if v is None:
            return v

        if v not in (1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 95, 96, 100, 101, 102, 103, 104, 105, 106, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 291, 300, 301, 303, 304, 305, 306, 307, 330, 331, 332, 333, 334, 400, 401, 402, 410, 411, 412, 501, 502, 503, 510, 511, 512, 513, 514, 515, 516, 517, 518, 519, 520, 521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 532, 533, 534, 535, 536, 537, 538, 539, 540, 541, 542, 545, 546, 550, 551, 552, 553, 554, 555, 600, 601, 602, 700, 701, 702, 703, 704, 705, 706, 800, 801, 802, 803, 804, 805, 900, 901, 902, 903, 904, 905, 906, 907, 911, 912, 931, 932, 950, 1001, 1002, 1010, 1100, 1101, 1200, 1201, 1244, 1245, 1300, 1301, 1302, 1303, 1304, 1305, 1400, 1401, 1402, 1403, 1404, 1405, 1406, 1407, 1408, 1409, 1410, 1411, 1412, 1413, 1414, 1415, 1416, 1417, 1418, 1419, 1420, 1421, 1422, 1423, 1424, 1500, 1501, 1502, 1503, 1504, 1505, 1506, 1507, 1508, 1509, 1510, 1511, 1512, 1513, 1514, 1600, 1601, 1602, 1603, 1604, 1605, 1606, 1607, 1608, 1609, 1700, 1701, 1702, 1801, 1802, 1900, 1901, 1902, 1903, 1904, 1905, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2100, 2101, 2102, 2103, 2104, 2105, 2106, 2107, 2108, 2109, 2110, 2111, 2112, 2113, 2114, 2201, 2202, 2203, 2204, 3000, 3001, 3002, 3003, 3004, 3005, 3006, 3007, 3008, 3009, 3010, 3011, 3012, 3013, 3014, 3015, 3016, 3017, 3018, 3019, 3020, 3021, 3022, 3023, 3024, 3025, 3026, 3027, 3028, 9000, 9001, 9002, 9003, 9004, 9005, 9006, 9007, 9008, 9009, 9010, 9011, 9012, 9013, 9014, 9015, 9016, 9017, 9018, 9019, 9020, 9021, 9022, 9023, 9024, 9025, 9026, 9027, 9028, 9029, 9030, 9031, 9032, 9033, 9034, 9035, 9036, 9037, 9038, 9039, 9040, 9041, 9042, 9043, 9044, 9045, 9046, 9047, 9048, 9049, 9050, 9051, 9052, 9053, 9054, 9055, 9056, 9057, 9058, 9059):
            raise ValueError("must validate the enum values (1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 95, 96, 100, 101, 102, 103, 104, 105, 106, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 291, 300, 301, 303, 304, 305, 306, 307, 330, 331, 332, 333, 334, 400, 401, 402, 410, 411, 412, 501, 502, 503, 510, 511, 512, 513, 514, 515, 516, 517, 518, 519, 520, 521, 522, 523, 524, 525, 526, 527, 528, 529, 530, 531, 532, 533, 534, 535, 536, 537, 538, 539, 540, 541, 542, 545, 546, 550, 551, 552, 553, 554, 555, 600, 601, 602, 700, 701, 702, 703, 704, 705, 706, 800, 801, 802, 803, 804, 805, 900, 901, 902, 903, 904, 905, 906, 907, 911, 912, 931, 932, 950, 1001, 1002, 1010, 1100, 1101, 1200, 1201, 1244, 1245, 1300, 1301, 1302, 1303, 1304, 1305, 1400, 1401, 1402, 1403, 1404, 1405, 1406, 1407, 1408, 1409, 1410, 1411, 1412, 1413, 1414, 1415, 1416, 1417, 1418, 1419, 1420, 1421, 1422, 1423, 1424, 1500, 1501, 1502, 1503, 1504, 1505, 1506, 1507, 1508, 1509, 1510, 1511, 1512, 1513, 1514, 1600, 1601, 1602, 1603, 1604, 1605, 1606, 1607, 1608, 1609, 1700, 1701, 1702, 1801, 1802, 1900, 1901, 1902, 1903, 1904, 1905, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2100, 2101, 2102, 2103, 2104, 2105, 2106, 2107, 2108, 2109, 2110, 2111, 2112, 2113, 2114, 2201, 2202, 2203, 2204, 3000, 3001, 3002, 3003, 3004, 3005, 3006, 3007, 3008, 3009, 3010, 3011, 3012, 3013, 3014, 3015, 3016, 3017, 3018, 3019, 3020, 3021, 3022, 3023, 3024, 3025, 3026, 3027, 3028, 9000, 9001, 9002, 9003, 9004, 9005, 9006, 9007, 9008, 9009, 9010, 9011, 9012, 9013, 9014, 9015, 9016, 9017, 9018, 9019, 9020, 9021, 9022, 9023, 9024, 9025, 9026, 9027, 9028, 9029, 9030, 9031, 9032, 9033, 9034, 9035, 9036, 9037, 9038, 9039, 9040, 9041, 9042, 9043, 9044, 9045, 9046, 9047, 9048, 9049, 9050, 9051, 9052, 9053, 9054, 9055, 9056, 9057, 9058, 9059)")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GetEvents200ResponseDataInner:
        """Create an instance of GetEvents200ResponseDataInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GetEvents200ResponseDataInner:
        """Create an instance of GetEvents200ResponseDataInner from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return GetEvents200ResponseDataInner.parse_obj(obj)

        _obj = GetEvents200ResponseDataInner.parse_obj({
            "account_id": obj.get("account_id"),
            "actor_system": obj.get("actor_system"),
            "actor_user_id": obj.get("actor_user_id"),
            "actor_user_name": obj.get("actor_user_name"),
            "adc_id": obj.get("adc_id"),
            "app_name": obj.get("app-name"),
            "app_id": obj.get("app_id"),
            "assumed_by_superadmin_or_reseller": obj.get("assumed_by_superadmin_or_reseller"),
            "assuming_acting_user_id": obj.get("assuming_acting_user_id"),
            "certificate_id": obj.get("certificate_id"),
            "client_id": obj.get("client_id"),
            "created_at": obj.get("created_at"),
            "custom_message": obj.get("custom_message"),
            "directory_sync_run_id": obj.get("directory_sync_run_id"),
            "error_description": obj.get("error_description"),
            "event_type_id": obj.get("event_type_id"),
            "group_name": obj.get("group-name"),
            "group_id": obj.get("group_id"),
            "id": obj.get("id"),
            "ipaddr": obj.get("ipaddr"),
            "mapping_id": obj.get("mapping_id"),
            "notes": obj.get("notes"),
            "object_id": obj.get("object_id"),
            "otp_device_id": obj.get("otp_device_id"),
            "otp_device_name": obj.get("otp_device_name"),
            "param": obj.get("param"),
            "policy_id": obj.get("policy_id"),
            "policy_name": obj.get("policy_name"),
            "policy_type": obj.get("policy_type"),
            "privilege_id": obj.get("privilege_id"),
            "proxy_ip": obj.get("proxy_ip"),
            "radius_config_id": obj.get("radius_config_id"),
            "resolved_at": obj.get("resolved_at"),
            "resource_type_id": obj.get("resource_type_id"),
            "risk_cookie_id": obj.get("risk_cookie_id"),
            "risk_reasons": obj.get("risk_reasons"),
            "risk_score": obj.get("risk_score"),
            "role_id": obj.get("role_id"),
            "role_name": obj.get("role_name"),
            "service_directory_id": obj.get("service_directory_id"),
            "solved": obj.get("solved"),
            "trusted_idp_id": obj.get("trusted_idp_id"),
            "user_field_id": obj.get("user_field_id"),
            "user_id": obj.get("user_id"),
            "user_name": obj.get("user_name")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.get_email_settings200_response_one_of1 import GetEmailSettings200ResponseOneOf1  # noqa: E501
from onelogin.rest import ApiException

class TestGetEmailSettings200ResponseOneOf1(unittest.TestCase):
    """GetEmailSettings200ResponseOneOf1 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GetEmailSettings200ResponseOneOf1
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetEmailSettings200ResponseOneOf1`
        """
        model = onelogin.models.get_email_settings200_response_one_of1.GetEmailSettings200ResponseOneOf1()  # noqa: E501
        if include_optional :
            return GetEmailSettings200ResponseOneOf1(
                address = 'smtp.sendgrid.net', 
                use_tls = True, 
                var_from = 'email@example.com', 
                domain = 'example.com', 
                user_name = 'user-name', 
                password = 'password', 
                port = 587
            )
        else :
            return GetEmailSettings200ResponseOneOf1(
                address = 'smtp.sendgrid.net',
                var_from = 'email@example.com',
                domain = 'example.com',
        )
        """

    def testGetEmailSettings200ResponseOneOf1(self):
        """Test GetEmailSettings200ResponseOneOf1"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, StrictInt, StrictStr
from onelogin.models.create_brand201_response_logo_urls import CreateBrand201ResponseLogoUrls

class CreateBrand201ResponseLogo(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    urls: CreateBrand201ResponseLogoUrls = ...
    file_size: StrictInt = ...
    updated_at: StrictStr = ...
    content_type: StrictStr = ...
    __properties = ["urls", "file_size", "updated_at", "content_type"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CreateBrand201ResponseLogo:
        """Create an instance of CreateBrand201ResponseLogo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of urls
        if self.urls:
            _dict['urls'] = self.urls.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CreateBrand201ResponseLogo:
        """Create an instance of CreateBrand201ResponseLogo from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CreateBrand201ResponseLogo.parse_obj(obj)

        _obj = CreateBrand201ResponseLogo.parse_obj({
            "urls": CreateBrand201ResponseLogoUrls.from_dict(obj.get("urls")) if obj.get("urls") is not None else None,
            "file_size": obj.get("file_size"),
            "updated_at": obj.get("updated_at"),
            "content_type": obj.get("content_type")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.create_app_request_one_of_configuration import CreateAppRequestOneOfConfiguration  # noqa: E501
from onelogin.rest import ApiException

class TestCreateAppRequestOneOfConfiguration(unittest.TestCase):
    """CreateAppRequestOneOfConfiguration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateAppRequestOneOfConfiguration
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateAppRequestOneOfConfiguration`
        """
        model = onelogin.models.create_app_request_one_of_configuration.CreateAppRequestOneOfConfiguration()  # noqa: E501
        if include_optional :
            return CreateAppRequestOneOfConfiguration(
                login_url = '', 
                redirect_uri = '', 
                access_token_expiration_minutes = 56, 
                refresh_token_expiration_minutes = 56, 
                token_endpoint_auth_method = 56, 
                oidc_application_type = 56
            )
        else :
            return CreateAppRequestOneOfConfiguration(
                login_url = '',
                redirect_uri = '',
                access_token_expiration_minutes = 56,
                refresh_token_expiration_minutes = 56,
                token_endpoint_auth_method = 56,
                oidc_application_type = 56,
        )
        """

    def testCreateAppRequestOneOfConfiguration(self):
        """Test CreateAppRequestOneOfConfiguration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "3.1.1"

# import apis into sdk package
from onelogin.api.api_auth_claims_api import APIAuthClaimsApi
from onelogin.api.api_auth_client_apps_api import APIAuthClientAppsApi
from onelogin.api.api_auth_scopes_api import APIAuthScopesApi
from onelogin.api.api_authorization_server_api import APIAuthorizationServerApi
from onelogin.api.app_rules_api import AppRulesApi
from onelogin.api.apps_api import AppsApi
from onelogin.api.branding_service_api import BrandingServiceApi
from onelogin.api.branding_service_smtp_api import BrandingServiceSMTPApi
from onelogin.api.branding_service_templates_api import BrandingServiceTemplatesApi
from onelogin.api.events_api import EventsApi
from onelogin.api.groups_api import GroupsApi
from onelogin.api.invite_links_api import InviteLinksApi
from onelogin.api.multi_factor_authentication_api import MultiFactorAuthenticationApi
from onelogin.api.multi_factor_authentication_v1_api import MultiFactorAuthenticationV1Api
from onelogin.api.o_auth2_api import OAuth2Api
from onelogin.api.privileges_api import PrivilegesApi
from onelogin.api.roles_api import RolesApi
from onelogin.api.saml_assertions_api import SAMLAssertionsApi
from onelogin.api.user_mappings_api import UserMappingsApi
from onelogin.api.users_v1_api import UsersV1Api
from onelogin.api.users_v2_api import UsersV2Api
from onelogin.api.vigilance_ai_api import VigilanceAIApi

# import ApiClient
from onelogin.api_client import ApiClient
from onelogin.configuration import Configuration
from onelogin.exceptions import OpenApiException
from onelogin.exceptions import ApiTypeError
from onelogin.exceptions import ApiValueError
from onelogin.exceptions import ApiKeyError
from onelogin.exceptions import ApiAttributeError
from onelogin.exceptions import ApiException
# import models into sdk package
from onelogin.models.activate_mfa_factors_request import ActivateMfaFactorsRequest
from onelogin.models.add_client_app201_response import AddClientApp201Response
from onelogin.models.add_client_app_request import AddClientAppRequest
from onelogin.models.add_privilege_to_role201_response import AddPrivilegeToRole201Response
from onelogin.models.add_privilege_to_role_request import AddPrivilegeToRoleRequest
from onelogin.models.add_roles_to_user_request import AddRolesToUserRequest
from onelogin.models.assign_users_to_privilege_request import AssignUsersToPrivilegeRequest
from onelogin.models.create_app_request import CreateAppRequest
from onelogin.models.create_app_request_one_of import CreateAppRequestOneOf
from onelogin.models.create_app_request_one_of1 import CreateAppRequestOneOf1
from onelogin.models.create_app_request_one_of1_configuration import CreateAppRequestOneOf1Configuration
from onelogin.models.create_app_request_one_of1_parameters import CreateAppRequestOneOf1Parameters
from onelogin.models.create_app_request_one_of1_parameters_saml_username import CreateAppRequestOneOf1ParametersSamlUsername
from onelogin.models.create_app_request_one_of_configuration import CreateAppRequestOneOfConfiguration
from onelogin.models.create_auth_claim_request import CreateAuthClaimRequest
from onelogin.models.create_brand201_response import CreateBrand201Response
from onelogin.models.create_brand201_response_background import CreateBrand201ResponseBackground
from onelogin.models.create_brand201_response_background_urls import CreateBrand201ResponseBackgroundUrls
from onelogin.models.create_brand201_response_logo import CreateBrand201ResponseLogo
from onelogin.models.create_brand201_response_logo_urls import CreateBrand201ResponseLogoUrls
from onelogin.models.create_brand_request import CreateBrandRequest
from onelogin.models.create_device_verification201_response import CreateDeviceVerification201Response
from onelogin.models.create_device_verification_request import CreateDeviceVerificationRequest
from onelogin.models.create_factor_registration201_response import CreateFactorRegistration201Response
from onelogin.models.create_factor_registration_request import CreateFactorRegistrationRequest
from onelogin.models.create_message_template_request import CreateMessageTemplateRequest
from onelogin.models.create_message_template_request_template import CreateMessageTemplateRequestTemplate
from onelogin.models.create_message_template_request_template_one_of import CreateMessageTemplateRequestTemplateOneOf
from onelogin.models.create_message_template_request_template_one_of1 import CreateMessageTemplateRequestTemplateOneOf1
from onelogin.models.create_message_template_request_template_one_of1_all_of import CreateMessageTemplateRequestTemplateOneOf1AllOf
from onelogin.models.create_message_template_request_template_one_of_all_of import CreateMessageTemplateRequestTemplateOneOfAllOf
from onelogin.models.create_privilege200_response import CreatePrivilege200Response
from onelogin.models.create_roles201_response_inner import CreateRoles201ResponseInner
from onelogin.models.create_scope200_response import CreateScope200Response
from onelogin.models.create_scope_request import CreateScopeRequest
from onelogin.models.enroll_mfa_factor200_response import EnrollMfaFactor200Response
from onelogin.models.enroll_mfa_factor_request import EnrollMfaFactorRequest
from onelogin.models.generate_mf_atoken200_response import GenerateMFAtoken200Response
from onelogin.models.generate_mf_atoken_request import GenerateMFAtokenRequest
from onelogin.models.generate_otp201_response import GenerateOTP201Response
from onelogin.models.generate_otp_request import GenerateOTPRequest
from onelogin.models.generate_saml_assert200_response import GenerateSamlAssert200Response
from onelogin.models.generate_saml_assert_request import GenerateSamlAssertRequest
from onelogin.models.generate_token200_response import GenerateToken200Response
from onelogin.models.generate_token400_response import GenerateToken400Response
from onelogin.models.generate_token_request import GenerateTokenRequest
from onelogin.models.get_assigned_user200_response import GetAssignedUser200Response
from onelogin.models.get_auth_factors200_response import GetAuthFactors200Response
from onelogin.models.get_authclaims200_response_inner import GetAuthclaims200ResponseInner
from onelogin.models.get_authentication_devices200_response_inner import GetAuthenticationDevices200ResponseInner
from onelogin.models.get_brand_apps200_response_inner import GetBrandApps200ResponseInner
from onelogin.models.get_custom_attributes200_response import GetCustomAttributes200Response
from onelogin.models.get_email_settings200_response import GetEmailSettings200Response
from onelogin.models.get_email_settings200_response_one_of import GetEmailSettings200ResponseOneOf
from onelogin.models.get_email_settings200_response_one_of1 import GetEmailSettings200ResponseOneOf1
from onelogin.models.get_enrolled_factors200_response import GetEnrolledFactors200Response
from onelogin.models.get_enrolled_factors200_response_data import GetEnrolledFactors200ResponseData
from onelogin.models.get_enrolled_factors200_response_data_otp_devices_inner import GetEnrolledFactors200ResponseDataOtpDevicesInner
from onelogin.models.get_event_by_id200_response import GetEventById200Response
from onelogin.models.get_event_by_id200_response_status import GetEventById200ResponseStatus
from onelogin.models.get_event_types200_response import GetEventTypes200Response
from onelogin.models.get_event_types200_response_data_inner import GetEventTypes200ResponseDataInner
from onelogin.models.get_events200_response import GetEvents200Response
from onelogin.models.get_events200_response_data_inner import GetEvents200ResponseDataInner
from onelogin.models.get_events200_response_pagination import GetEvents200ResponsePagination
from onelogin.models.get_groups200_response import GetGroups200Response
from onelogin.models.get_groups200_response_data_inner import GetGroups200ResponseDataInner
from onelogin.models.get_invite_link200_response import GetInviteLink200Response
from onelogin.models.get_invite_link_request import GetInviteLinkRequest
from onelogin.models.get_mfa_factors200_response import GetMFAFactors200Response
from onelogin.models.get_mfa_factors200_response_data import GetMFAFactors200ResponseData
from onelogin.models.get_mfa_factors200_response_data_auth_factors_inner import GetMFAFactors200ResponseDataAuthFactorsInner
from onelogin.models.get_rate_limit200_response import GetRateLimit200Response
from onelogin.models.get_rate_limit200_response_data import GetRateLimit200ResponseData
from onelogin.models.get_risk_score200_response import GetRiskScore200Response
from onelogin.models.get_risk_score_request import GetRiskScoreRequest
from onelogin.models.get_risk_scores200_response import GetRiskScores200Response
from onelogin.models.get_risk_scores200_response_scores import GetRiskScores200ResponseScores
from onelogin.models.get_role_apps200_response_inner import GetRoleApps200ResponseInner
from onelogin.models.get_role_by_id200_response import GetRoleById200Response
from onelogin.models.get_role_by_id200_response_data_inner import GetRoleById200ResponseDataInner
from onelogin.models.get_role_by_name200_response import GetRoleByName200Response
from onelogin.models.get_role_by_name200_response_data_inner import GetRoleByName200ResponseDataInner
from onelogin.models.get_role_by_name200_response_pagination import GetRoleByName200ResponsePagination
from onelogin.models.get_scopes200_response_inner import GetScopes200ResponseInner
from onelogin.models.get_scopes200_response_inner_configuration import GetScopes200ResponseInnerConfiguration
from onelogin.models.get_scopes401_response import GetScopes401Response
from onelogin.models.get_user_apps200_response_inner import GetUserApps200ResponseInner
from onelogin.models.get_user_roles200_response import GetUserRoles200Response
from onelogin.models.get_user_verification200_response import GetUserVerification200Response
from onelogin.models.list_actions200_response_inner import ListActions200ResponseInner
from onelogin.models.list_app_rules200_response_inner import ListAppRules200ResponseInner
from onelogin.models.list_apps200_response import ListApps200Response
from onelogin.models.list_apps200_response_provisioning import ListApps200ResponseProvisioning
from onelogin.models.list_brands200_response_inner import ListBrands200ResponseInner
from onelogin.models.list_client_apps200_response import ListClientApps200Response
from onelogin.models.list_client_apps200_response_scopes_inner import ListClientApps200ResponseScopesInner
from onelogin.models.list_condition_operators200_response_inner import ListConditionOperators200ResponseInner
from onelogin.models.list_conditions200_response_inner import ListConditions200ResponseInner
from onelogin.models.list_connectors200_response import ListConnectors200Response
from onelogin.models.list_mapping_action_values200_response_inner import ListMappingActionValues200ResponseInner
from onelogin.models.list_mapping_conditions200_response import ListMappingConditions200Response
from onelogin.models.list_mapping_conditions_operators200_response_inner import ListMappingConditionsOperators200ResponseInner
from onelogin.models.list_mapping_contion_values200_response_inner import ListMappingContionValues200ResponseInner
from onelogin.models.list_mappings200_response_inner import ListMappings200ResponseInner
from onelogin.models.list_mappings200_response_inner_actions_inner import ListMappings200ResponseInnerActionsInner
from onelogin.models.list_mappings200_response_inner_conditions_inner import ListMappings200ResponseInnerConditionsInner
from onelogin.models.list_mappings_actions200_response_inner import ListMappingsActions200ResponseInner
from onelogin.models.list_message_templates200_response_inner import ListMessageTemplates200ResponseInner
from onelogin.models.list_privelege_roles200_response import ListPrivelegeRoles200Response
from onelogin.models.list_priveleges200_response_inner import ListPriveleges200ResponseInner
from onelogin.models.list_priveleges200_response_inner_privilege import ListPriveleges200ResponseInnerPrivilege
from onelogin.models.list_priveleges200_response_inner_privilege_statement_inner import ListPriveleges200ResponseInnerPrivilegeStatementInner
from onelogin.models.list_risk_rules200_response_inner import ListRiskRules200ResponseInner
from onelogin.models.list_risk_rules200_response_inner_source import ListRiskRules200ResponseInnerSource
from onelogin.models.list_roles200_response_inner import ListRoles200ResponseInner
from onelogin.models.list_users200_response_inner import ListUsers200ResponseInner
from onelogin.models.lock_account_user_request import LockAccountUserRequest
from onelogin.models.remove_role_users_request import RemoveRoleUsersRequest
from onelogin.models.remove_user_role_request import RemoveUserRoleRequest
from onelogin.models.remove_user_role_request_role_id_array_inner import RemoveUserRoleRequestRoleIdArrayInner
from onelogin.models.revoke_tokens_request import RevokeTokensRequest
from onelogin.models.send_invite_link200_response import SendInviteLink200Response
from onelogin.models.send_invite_link_request import SendInviteLinkRequest
from onelogin.models.set_user_state_request import SetUserStateRequest
from onelogin.models.track_risk_event_request import TrackRiskEventRequest
from onelogin.models.track_risk_event_request_device import TrackRiskEventRequestDevice
from onelogin.models.track_risk_event_request_session import TrackRiskEventRequestSession
from onelogin.models.track_risk_event_request_user import TrackRiskEventRequestUser
from onelogin.models.update_client_app_request import UpdateClientAppRequest
from onelogin.models.update_password_insecure_request import UpdatePasswordInsecureRequest
from onelogin.models.update_password_secure_request import UpdatePasswordSecureRequest
from onelogin.models.update_privilege200_response import UpdatePrivilege200Response
from onelogin.models.update_risk_rule_request import UpdateRiskRuleRequest
from onelogin.models.ver_factor_saml200_response import VerFactorSaml200Response
from onelogin.models.ver_factor_saml_request import VerFactorSamlRequest
from onelogin.models.verify_mfa_factor_request import VerifyMfaFactorRequest
from onelogin.models.verify_user_registration200_response import VerifyUserRegistration200Response
from onelogin.models.verify_user_registration_request import VerifyUserRegistrationRequest
from onelogin.models.verify_user_verification_request import VerifyUserVerificationRequest



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.list_client_apps200_response import ListClientApps200Response  # noqa: E501
from onelogin.rest import ApiException

class TestListClientApps200Response(unittest.TestCase):
    """ListClientApps200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListClientApps200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListClientApps200Response`
        """
        model = onelogin.models.list_client_apps200_response.ListClientApps200Response()  # noqa: E501
        if include_optional :
            return ListClientApps200Response(
                scopes = [
                    onelogin.models.list_client_apps_200_response_scopes_inner.listClientApps_200_response_scopes_inner(
                        id = 25, 
                        value = 'read:contacts', 
                        description = 'Read some contacts', )
                    ], 
                app_id = 1026152, 
                name = 'An oidc app', 
                api_auth_id = 1033034
            )
        else :
            return ListClientApps200Response(
        )
        """

    def testListClientApps200Response(self):
        """Test ListClientApps200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.create_brand201_response_logo import CreateBrand201ResponseLogo  # noqa: E501
from onelogin.rest import ApiException

class TestCreateBrand201ResponseLogo(unittest.TestCase):
    """CreateBrand201ResponseLogo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateBrand201ResponseLogo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateBrand201ResponseLogo`
        """
        model = onelogin.models.create_brand201_response_logo.CreateBrand201ResponseLogo()  # noqa: E501
        if include_optional :
            return CreateBrand201ResponseLogo(
                urls = onelogin.models.create_brand_201_response_logo_urls.createBrand_201_response_logo_urls(
                    original = '', 
                    login = '', 
                    navigation = '', ), 
                file_size = 56, 
                updated_at = '', 
                content_type = ''
            )
        else :
            return CreateBrand201ResponseLogo(
                urls = onelogin.models.create_brand_201_response_logo_urls.createBrand_201_response_logo_urls(
                    original = '', 
                    login = '', 
                    navigation = '', ),
                file_size = 56,
                updated_at = '',
                content_type = '',
        )
        """

    def testCreateBrand201ResponseLogo(self):
        """Test CreateBrand201ResponseLogo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.create_app_request_one_of1 import CreateAppRequestOneOf1  # noqa: E501
from onelogin.rest import ApiException

class TestCreateAppRequestOneOf1(unittest.TestCase):
    """CreateAppRequestOneOf1 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateAppRequestOneOf1
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateAppRequestOneOf1`
        """
        model = onelogin.models.create_app_request_one_of1.CreateAppRequestOneOf1()  # noqa: E501
        if include_optional :
            return CreateAppRequestOneOf1(
                connector_id = 56, 
                name = '', 
                description = '', 
                visible = True, 
                policy_id = 56, 
                configuration = onelogin.models.create_app_request_one_of_1_configuration.createApp_request_oneOf_1_configuration(
                    signature_algorithm = '', 
                    certificate_id = 56, ), 
                parameters = onelogin.models.create_app_request_one_of_1_parameters.createApp_request_oneOf_1_parameters(
                    saml_username = onelogin.models.create_app_request_one_of_1_parameters_saml_username.createApp_request_oneOf_1_parameters_saml_username(
                        user_attribute_mappings = '', ), )
            )
        else :
            return CreateAppRequestOneOf1(
                connector_id = 56,
                name = '',
                description = '',
                visible = True,
                policy_id = 56,
                configuration = onelogin.models.create_app_request_one_of_1_configuration.createApp_request_oneOf_1_configuration(
                    signature_algorithm = '', 
                    certificate_id = 56, ),
                parameters = onelogin.models.create_app_request_one_of_1_parameters.createApp_request_oneOf_1_parameters(
                    saml_username = onelogin.models.create_app_request_one_of_1_parameters_saml_username.createApp_request_oneOf_1_parameters_saml_username(
                        user_attribute_mappings = '', ), ),
        )
        """

    def testCreateAppRequestOneOf1(self):
        """Test CreateAppRequestOneOf1"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt

class GenerateOTPRequest(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    expires_in: Optional[StrictInt] = Field(None, description="Set the duration of the token in seconds. Token expiration defaults to 259200 seconds = 72 hours. 72 hours is the max value.")
    reusable: Optional[StrictBool] = Field(False, description="Defines if the token is reusable multiple times within the expiry window. Value defaults to false. If set to true, token can be used multiple times, until it expires.")
    __properties = ["expires_in", "reusable"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> GenerateOTPRequest:
        """Create an instance of GenerateOTPRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> GenerateOTPRequest:
        """Create an instance of GenerateOTPRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return GenerateOTPRequest.parse_obj(obj)

        _obj = GenerateOTPRequest.parse_obj({
            "expires_in": obj.get("expires_in"),
            "reusable": obj.get("reusable") if obj.get("reusable") is not None else False
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.list_users200_response_inner import ListUsers200ResponseInner  # noqa: E501
from onelogin.rest import ApiException

class TestListUsers200ResponseInner(unittest.TestCase):
    """ListUsers200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListUsers200ResponseInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListUsers200ResponseInner`
        """
        model = onelogin.models.list_users200_response_inner.ListUsers200ResponseInner()  # noqa: E501
        if include_optional :
            return ListUsers200ResponseInner(
                id = 56, 
                username = '', 
                email = '', 
                firstname = '', 
                lastname = '', 
                title = '', 
                department = '', 
                company = '', 
                comment = '', 
                group_id = 56, 
                role_ids = [
                    56
                    ], 
                phone = '', 
                state = 0, 
                status = 0, 
                directory_id = 56, 
                trusted_idp_id = 56, 
                manager_ad_id = '', 
                manager_user_id = '', 
                samaccount_name = '', 
                member_of = '', 
                userprincipalname = '', 
                distinguished_name = '', 
                external_id = '', 
                activated_at = '', 
                last_login = '', 
                invitation_sent_at = '', 
                updated_at = '', 
                preferred_locale_code = '', 
                created_at = '', 
                invalid_login_attempts = 56, 
                locked_until = '', 
                password_changed_at = '', 
                password = '', 
                password_confirmation = '', 
                password_algorithm = '', 
                salt = ''
            )
        else :
            return ListUsers200ResponseInner(
        )
        """

    def testListUsers200ResponseInner(self):
        """Test ListUsers200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.get_authclaims200_response_inner import GetAuthclaims200ResponseInner  # noqa: E501
from onelogin.rest import ApiException

class TestGetAuthclaims200ResponseInner(unittest.TestCase):
    """GetAuthclaims200ResponseInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GetAuthclaims200ResponseInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetAuthclaims200ResponseInner`
        """
        model = onelogin.models.get_authclaims200_response_inner.GetAuthclaims200ResponseInner()  # noqa: E501
        if include_optional :
            return GetAuthclaims200ResponseInner(
                id = 320780, 
                label = 'email_address', 
                user_attribute_mappings = 'email', 
                user_attribute_macros = '', 
                attribute_transformations = '', 
                skip_if_blank = True, 
                values = [], 
                default_values = '', 
                provisioned_entitlements = True
            )
        else :
            return GetAuthclaims200ResponseInner(
        )
        """

    def testGetAuthclaims200ResponseInner(self):
        """Test GetAuthclaims200ResponseInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from pydantic import Field, StrictInt, StrictStr, constr, validator

from typing import List, Optional

from onelogin.models.create_message_template_request import CreateMessageTemplateRequest
from onelogin.models.list_message_templates200_response_inner import ListMessageTemplates200ResponseInner

from onelogin.api_client import ApiClient
from onelogin.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class BrandingServiceTemplatesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def create_message_template(self, brand_id : Annotated[StrictInt, Field(..., description="Unique identifier for the branding object.")], locale : Annotated[constr(strict=True), Field(..., description="The 2 character language locale for the template. e.g. en = English, es = Spanish")], create_message_template_request : Optional[CreateMessageTemplateRequest] = None, **kwargs) -> CreateMessageTemplateRequest:  # noqa: E501
        """Create Message Template  # noqa: E501

        Create Message Template  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_message_template(brand_id, locale, create_message_template_request, async_req=True)
        >>> result = thread.get()

        :param brand_id: Unique identifier for the branding object. (required)
        :type brand_id: int
        :param locale: The 2 character language locale for the template. e.g. en = English, es = Spanish (required)
        :type locale: str
        :param create_message_template_request:
        :type create_message_template_request: CreateMessageTemplateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CreateMessageTemplateRequest
        """
        kwargs['_return_http_data_only'] = True
        return self.create_message_template_with_http_info(brand_id, locale, create_message_template_request, **kwargs)  # noqa: E501

    @validate_arguments
    def create_message_template_with_http_info(self, brand_id : Annotated[StrictInt, Field(..., description="Unique identifier for the branding object.")], locale : Annotated[constr(strict=True), Field(..., description="The 2 character language locale for the template. e.g. en = English, es = Spanish")], create_message_template_request : Optional[CreateMessageTemplateRequest] = None, **kwargs):  # noqa: E501
        """Create Message Template  # noqa: E501

        Create Message Template  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_message_template_with_http_info(brand_id, locale, create_message_template_request, async_req=True)
        >>> result = thread.get()

        :param brand_id: Unique identifier for the branding object. (required)
        :type brand_id: int
        :param locale: The 2 character language locale for the template. e.g. en = English, es = Spanish (required)
        :type locale: str
        :param create_message_template_request:
        :type create_message_template_request: CreateMessageTemplateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CreateMessageTemplateRequest, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'brand_id',
            'locale',
            'create_message_template_request'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_message_template" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['brand_id']:
            _path_params['brand_id'] = _params['brand_id']

        # process the query parameters
        _query_params = []
        if _params.get('locale') is not None:  # noqa: E501
            _query_params.append(('locale', _params['locale']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None
        if _params['create_message_template_request']:
            _body_params = _params['create_message_template_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['OAuth2']  # noqa: E501

        _response_types_map = {
            '200': "CreateMessageTemplateRequest",
            '401': "GetScopes401Response",
            '422': "GetScopes401Response",
        }

        return self.api_client.call_api(
            '/api/2/branding/brands/{brand_id}/templates', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def delete_message_template(self, brand_id : Annotated[StrictInt, Field(..., description="Unique identifier for the branding object.")], template_id : Annotated[StrictInt, Field(..., description="Unique identifier for the template to return.")], **kwargs) -> None:  # noqa: E501
        """Delete Message Template  # noqa: E501

        Delete Message Template  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_message_template(brand_id, template_id, async_req=True)
        >>> result = thread.get()

        :param brand_id: Unique identifier for the branding object. (required)
        :type brand_id: int
        :param template_id: Unique identifier for the template to return. (required)
        :type template_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_message_template_with_http_info(brand_id, template_id, **kwargs)  # noqa: E501

    @validate_arguments
    def delete_message_template_with_http_info(self, brand_id : Annotated[StrictInt, Field(..., description="Unique identifier for the branding object.")], template_id : Annotated[StrictInt, Field(..., description="Unique identifier for the template to return.")], **kwargs):  # noqa: E501
        """Delete Message Template  # noqa: E501

        Delete Message Template  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_message_template_with_http_info(brand_id, template_id, async_req=True)
        >>> result = thread.get()

        :param brand_id: Unique identifier for the branding object. (required)
        :type brand_id: int
        :param template_id: Unique identifier for the template to return. (required)
        :type template_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = [
            'brand_id',
            'template_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_message_template" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['brand_id']:
            _path_params['brand_id'] = _params['brand_id']
        if _params['template_id']:
            _path_params['template_id'] = _params['template_id']

        # process the query parameters
        _query_params = []

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['OAuth2']  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            '/api/2/branding/brands/{brand_id}/templates/{template_id}', 'DELETE',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_master_by_type(self, template_type : Annotated[StrictStr, Field(..., description="The message template type to return.")], **kwargs) -> CreateMessageTemplateRequest:  # noqa: E501
        """Get Master Template by Type  # noqa: E501

        Get Master Template by Type  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_master_by_type(template_type, async_req=True)
        >>> result = thread.get()

        :param template_type: The message template type to return. (required)
        :type template_type: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CreateMessageTemplateRequest
        """
        kwargs['_return_http_data_only'] = True
        return self.get_master_by_type_with_http_info(template_type, **kwargs)  # noqa: E501

    @validate_arguments
    def get_master_by_type_with_http_info(self, template_type : Annotated[StrictStr, Field(..., description="The message template type to return.")], **kwargs):  # noqa: E501
        """Get Master Template by Type  # noqa: E501

        Get Master Template by Type  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_master_by_type_with_http_info(template_type, async_req=True)
        >>> result = thread.get()

        :param template_type: The message template type to return. (required)
        :type template_type: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CreateMessageTemplateRequest, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'template_type'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_master_by_type" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['template_type']:
            _path_params['template_type'] = _params['template_type']

        # process the query parameters
        _query_params = []

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['OAuth2']  # noqa: E501

        _response_types_map = {
            '200': "CreateMessageTemplateRequest",
            '401': "GetScopes401Response",
            '404': "GetScopes401Response",
        }

        return self.api_client.call_api(
            '/api/2/branding/brands/master/templates/{template_type}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_message_template_by_id(self, brand_id : Annotated[StrictInt, Field(..., description="Unique identifier for the branding object.")], template_id : Annotated[StrictInt, Field(..., description="Unique identifier for the template to return.")], **kwargs) -> CreateMessageTemplateRequest:  # noqa: E501
        """Get Message Template  # noqa: E501

        Get Message Template by ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_message_template_by_id(brand_id, template_id, async_req=True)
        >>> result = thread.get()

        :param brand_id: Unique identifier for the branding object. (required)
        :type brand_id: int
        :param template_id: Unique identifier for the template to return. (required)
        :type template_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CreateMessageTemplateRequest
        """
        kwargs['_return_http_data_only'] = True
        return self.get_message_template_by_id_with_http_info(brand_id, template_id, **kwargs)  # noqa: E501

    @validate_arguments
    def get_message_template_by_id_with_http_info(self, brand_id : Annotated[StrictInt, Field(..., description="Unique identifier for the branding object.")], template_id : Annotated[StrictInt, Field(..., description="Unique identifier for the template to return.")], **kwargs):  # noqa: E501
        """Get Message Template  # noqa: E501

        Get Message Template by ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_message_template_by_id_with_http_info(brand_id, template_id, async_req=True)
        >>> result = thread.get()

        :param brand_id: Unique identifier for the branding object. (required)
        :type brand_id: int
        :param template_id: Unique identifier for the template to return. (required)
        :type template_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CreateMessageTemplateRequest, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'brand_id',
            'template_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_message_template_by_id" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['brand_id']:
            _path_params['brand_id'] = _params['brand_id']
        if _params['template_id']:
            _path_params['template_id'] = _params['template_id']

        # process the query parameters
        _query_params = []

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['OAuth2']  # noqa: E501

        _response_types_map = {
            '200': "CreateMessageTemplateRequest",
            '401': "GetScopes401Response",
            '404': "GetScopes401Response",
        }

        return self.api_client.call_api(
            '/api/2/branding/brands/{brand_id}/templates/{template_id}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_template_by_locale(self, brand_id : Annotated[StrictInt, Field(..., description="Unique identifier for the branding object.")], template_type : Annotated[StrictStr, Field(..., description="The message template type to return.")], locale : Annotated[constr(strict=True), Field(..., description="The 2 character language locale for the template. e.g. en = English, es = Spanish")], **kwargs) -> CreateMessageTemplateRequest:  # noqa: E501
        """Get Template by Type & Locale  # noqa: E501

        Get Template by Type and Locale  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_template_by_locale(brand_id, template_type, locale, async_req=True)
        >>> result = thread.get()

        :param brand_id: Unique identifier for the branding object. (required)
        :type brand_id: int
        :param template_type: The message template type to return. (required)
        :type template_type: str
        :param locale: The 2 character language locale for the template. e.g. en = English, es = Spanish (required)
        :type locale: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CreateMessageTemplateRequest
        """
        kwargs['_return_http_data_only'] = True
        return self.get_template_by_locale_with_http_info(brand_id, template_type, locale, **kwargs)  # noqa: E501

    @validate_arguments
    def get_template_by_locale_with_http_info(self, brand_id : Annotated[StrictInt, Field(..., description="Unique identifier for the branding object.")], template_type : Annotated[StrictStr, Field(..., description="The message template type to return.")], locale : Annotated[constr(strict=True), Field(..., description="The 2 character language locale for the template. e.g. en = English, es = Spanish")], **kwargs):  # noqa: E501
        """Get Template by Type & Locale  # noqa: E501

        Get Template by Type and Locale  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_template_by_locale_with_http_info(brand_id, template_type, locale, async_req=True)
        >>> result = thread.get()

        :param brand_id: Unique identifier for the branding object. (required)
        :type brand_id: int
        :param template_type: The message template type to return. (required)
        :type template_type: str
        :param locale: The 2 character language locale for the template. e.g. en = English, es = Spanish (required)
        :type locale: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CreateMessageTemplateRequest, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'brand_id',
            'template_type',
            'locale'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_template_by_locale" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['brand_id']:
            _path_params['brand_id'] = _params['brand_id']
        if _params['template_type']:
            _path_params['template_type'] = _params['template_type']
        if _params['locale']:
            _path_params['locale'] = _params['locale']

        # process the query parameters
        _query_params = []

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['OAuth2']  # noqa: E501

        _response_types_map = {
            '200': "CreateMessageTemplateRequest",
            '401': "GetScopes401Response",
            '404': "GetScopes401Response",
        }

        return self.api_client.call_api(
            '/api/2/branding/brands/{brand_id}/templates/{template_type}/{locale}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def list_message_templates(self, brand_id : Annotated[StrictInt, Field(..., description="Unique identifier for the branding object.")], locale : Annotated[constr(strict=True), Field(..., description="The 2 character language locale for the template. e.g. en = English, es = Spanish")], **kwargs) -> List[ListMessageTemplates200ResponseInner]:  # noqa: E501
        """List Message Templates  # noqa: E501

        List Message Templates  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_message_templates(brand_id, locale, async_req=True)
        >>> result = thread.get()

        :param brand_id: Unique identifier for the branding object. (required)
        :type brand_id: int
        :param locale: The 2 character language locale for the template. e.g. en = English, es = Spanish (required)
        :type locale: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: List[ListMessageTemplates200ResponseInner]
        """
        kwargs['_return_http_data_only'] = True
        return self.list_message_templates_with_http_info(brand_id, locale, **kwargs)  # noqa: E501

    @validate_arguments
    def list_message_templates_with_http_info(self, brand_id : Annotated[StrictInt, Field(..., description="Unique identifier for the branding object.")], locale : Annotated[constr(strict=True), Field(..., description="The 2 character language locale for the template. e.g. en = English, es = Spanish")], **kwargs):  # noqa: E501
        """List Message Templates  # noqa: E501

        List Message Templates  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_message_templates_with_http_info(brand_id, locale, async_req=True)
        >>> result = thread.get()

        :param brand_id: Unique identifier for the branding object. (required)
        :type brand_id: int
        :param locale: The 2 character language locale for the template. e.g. en = English, es = Spanish (required)
        :type locale: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(List[ListMessageTemplates200ResponseInner], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'brand_id',
            'locale'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_message_templates" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['brand_id']:
            _path_params['brand_id'] = _params['brand_id']

        # process the query parameters
        _query_params = []
        if _params.get('locale') is not None:  # noqa: E501
            _query_params.append(('locale', _params['locale']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['OAuth2']  # noqa: E501

        _response_types_map = {
            '200': "List[ListMessageTemplates200ResponseInner]",
            '401': "GetScopes401Response",
            '422': "GetScopes401Response",
        }

        return self.api_client.call_api(
            '/api/2/branding/brands/{brand_id}/templates', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def update_message_template_by_id(self, brand_id : Annotated[StrictInt, Field(..., description="Unique identifier for the branding object.")], template_id : Annotated[StrictInt, Field(..., description="Unique identifier for the template to return.")], **kwargs) -> CreateMessageTemplateRequest:  # noqa: E501
        """Update Message Template  # noqa: E501

        Update Message Template by ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_message_template_by_id(brand_id, template_id, async_req=True)
        >>> result = thread.get()

        :param brand_id: Unique identifier for the branding object. (required)
        :type brand_id: int
        :param template_id: Unique identifier for the template to return. (required)
        :type template_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CreateMessageTemplateRequest
        """
        kwargs['_return_http_data_only'] = True
        return self.update_message_template_by_id_with_http_info(brand_id, template_id, **kwargs)  # noqa: E501

    @validate_arguments
    def update_message_template_by_id_with_http_info(self, brand_id : Annotated[StrictInt, Field(..., description="Unique identifier for the branding object.")], template_id : Annotated[StrictInt, Field(..., description="Unique identifier for the template to return.")], **kwargs):  # noqa: E501
        """Update Message Template  # noqa: E501

        Update Message Template by ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_message_template_by_id_with_http_info(brand_id, template_id, async_req=True)
        >>> result = thread.get()

        :param brand_id: Unique identifier for the branding object. (required)
        :type brand_id: int
        :param template_id: Unique identifier for the template to return. (required)
        :type template_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CreateMessageTemplateRequest, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'brand_id',
            'template_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_message_template_by_id" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['brand_id']:
            _path_params['brand_id'] = _params['brand_id']
        if _params['template_id']:
            _path_params['template_id'] = _params['template_id']

        # process the query parameters
        _query_params = []

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['OAuth2']  # noqa: E501

        _response_types_map = {
            '200': "CreateMessageTemplateRequest",
            '401': "GetScopes401Response",
            '422': "GetScopes401Response",
        }

        return self.api_client.call_api(
            '/api/2/branding/brands/{brand_id}/templates/{template_id}', 'PUT',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def update_template_by_locale(self, brand_id : Annotated[StrictInt, Field(..., description="Unique identifier for the branding object.")], template_type : Annotated[StrictStr, Field(..., description="The message template type to return.")], locale : Annotated[constr(strict=True), Field(..., description="The 2 character language locale for the template. e.g. en = English, es = Spanish")], **kwargs) -> CreateMessageTemplateRequest:  # noqa: E501
        """Update Template by Type & Locale  # noqa: E501

        Update Template by Type and Locale  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_template_by_locale(brand_id, template_type, locale, async_req=True)
        >>> result = thread.get()

        :param brand_id: Unique identifier for the branding object. (required)
        :type brand_id: int
        :param template_type: The message template type to return. (required)
        :type template_type: str
        :param locale: The 2 character language locale for the template. e.g. en = English, es = Spanish (required)
        :type locale: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CreateMessageTemplateRequest
        """
        kwargs['_return_http_data_only'] = True
        return self.update_template_by_locale_with_http_info(brand_id, template_type, locale, **kwargs)  # noqa: E501

    @validate_arguments
    def update_template_by_locale_with_http_info(self, brand_id : Annotated[StrictInt, Field(..., description="Unique identifier for the branding object.")], template_type : Annotated[StrictStr, Field(..., description="The message template type to return.")], locale : Annotated[constr(strict=True), Field(..., description="The 2 character language locale for the template. e.g. en = English, es = Spanish")], **kwargs):  # noqa: E501
        """Update Template by Type & Locale  # noqa: E501

        Update Template by Type and Locale  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_template_by_locale_with_http_info(brand_id, template_type, locale, async_req=True)
        >>> result = thread.get()

        :param brand_id: Unique identifier for the branding object. (required)
        :type brand_id: int
        :param template_type: The message template type to return. (required)
        :type template_type: str
        :param locale: The 2 character language locale for the template. e.g. en = English, es = Spanish (required)
        :type locale: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CreateMessageTemplateRequest, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'brand_id',
            'template_type',
            'locale'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_template_by_locale" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['brand_id']:
            _path_params['brand_id'] = _params['brand_id']
        if _params['template_type']:
            _path_params['template_type'] = _params['template_type']
        if _params['locale']:
            _path_params['locale'] = _params['locale']

        # process the query parameters
        _query_params = []

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))

        # process the form parameters
        _form_params = []
        _files = {}

        # process the body parameter
        _body_params = None

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['OAuth2']  # noqa: E501

        _response_types_map = {
            '200': "CreateMessageTemplateRequest",
            '401': "GetScopes401Response",
            '404': "GetScopes401Response",
        }

        return self.api_client.call_api(
            '/api/2/branding/brands/{brand_id}/templates/{template_type}/{locale}', 'PUT',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictStr
from onelogin.models.list_priveleges200_response_inner_privilege_statement_inner import ListPriveleges200ResponseInnerPrivilegeStatementInner

class ListPriveleges200ResponseInnerPrivilege(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    version: Optional[StrictStr] = Field(None, alias="Version")
    statement: Optional[List[ListPriveleges200ResponseInnerPrivilegeStatementInner]] = Field(None, alias="Statement")
    __properties = ["Version", "Statement"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ListPriveleges200ResponseInnerPrivilege:
        """Create an instance of ListPriveleges200ResponseInnerPrivilege from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in statement (list)
        _items = []
        if self.statement:
            for _item in self.statement:
                if _item:
                    _items.append(_item.to_dict())
            _dict['Statement'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ListPriveleges200ResponseInnerPrivilege:
        """Create an instance of ListPriveleges200ResponseInnerPrivilege from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ListPriveleges200ResponseInnerPrivilege.parse_obj(obj)

        _obj = ListPriveleges200ResponseInnerPrivilege.parse_obj({
            "version": obj.get("Version"),
            "statement": [ListPriveleges200ResponseInnerPrivilegeStatementInner.from_dict(_item) for _item in obj.get("Statement")] if obj.get("Statement") is not None else None
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.list_connectors200_response import ListConnectors200Response  # noqa: E501
from onelogin.rest import ApiException

class TestListConnectors200Response(unittest.TestCase):
    """ListConnectors200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListConnectors200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListConnectors200Response`
        """
        model = onelogin.models.list_connectors200_response.ListConnectors200Response()  # noqa: E501
        if include_optional :
            return ListConnectors200Response(
                id = 1061937, 
                name = 'Amazon Web Services Multi-Role', 
                icon_url = 'https://cdn-shadow.onlgn.net/images/icons/square/amazonwebservices3multirole/old_original.png?1421095823', 
                auth_method = 2, 
                allows_new_parameters = True
            )
        else :
            return ListConnectors200Response(
        )
        """

    def testListConnectors200Response(self):
        """Test ListConnectors200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.ver_factor_saml_request import VerFactorSamlRequest  # noqa: E501
from onelogin.rest import ApiException

class TestVerFactorSamlRequest(unittest.TestCase):
    """VerFactorSamlRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test VerFactorSamlRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VerFactorSamlRequest`
        """
        model = onelogin.models.ver_factor_saml_request.VerFactorSamlRequest()  # noqa: E501
        if include_optional :
            return VerFactorSamlRequest(
                app_id = '1657651', 
                device_id = '1657651', 
                state_token = '11x0x1x16x1x3259xxxx0x59xx6xxxx670x61x45xxxxx', 
                otp_token = '999999', 
                do_not_notify = False
            )
        else :
            return VerFactorSamlRequest(
                app_id = '1657651',
                device_id = '1657651',
                state_token = '11x0x1x16x1x3259xxxx0x59xx6xxxx670x61x45xxxxx',
        )
        """

    def testVerFactorSamlRequest(self):
        """Test VerFactorSamlRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.create_brand201_response import CreateBrand201Response  # noqa: E501
from onelogin.rest import ApiException

class TestCreateBrand201Response(unittest.TestCase):
    """CreateBrand201Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateBrand201Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CreateBrand201Response`
        """
        model = onelogin.models.create_brand201_response.CreateBrand201Response()  # noqa: E501
        if include_optional :
            return CreateBrand201Response(
                id = 56, 
                enabled = True, 
                custom_support_enabled = False, 
                custom_color = '#1298b4', 
                custom_accent_color = '#b60012', 
                custom_masking_color = '#beefed', 
                custom_masking_opacity = 40, 
                mfa_enrollment_message = 'You must register with the OneLogin Protect app in order to login', 
                enable_custom_label_for_login_screen = True, 
                custom_label_text_for_login_screen = 'ACME Username or Email', 
                login_instruction = 'To login, enter your ACME Username or Email. Reach out to help.desk@acme.org if you have trouble logging in.', 
                login_instruction_title = 'ACME Login Instructions', 
                hide_onelogin_footer = True, 
                background = onelogin.models.create_brand_201_response_background.createBrand_201_response_background(
                    urls = onelogin.models.create_brand_201_response_background_urls.createBrand_201_response_background_urls(
                        original = '', 
                        login = '', 
                        branding = '', ), 
                    file_size = 56, 
                    updated_at = '', 
                    content_type = '', ), 
                logo = onelogin.models.create_brand_201_response_logo.createBrand_201_response_logo(
                    urls = onelogin.models.create_brand_201_response_logo_urls.createBrand_201_response_logo_urls(
                        original = '', 
                        login = '', 
                        navigation = '', ), 
                    file_size = 56, 
                    updated_at = '', 
                    content_type = '', )
            )
        else :
            return CreateBrand201Response(
                id = 56,
                enabled = True,
                custom_support_enabled = False,
                custom_color = '#1298b4',
                custom_accent_color = '#b60012',
                custom_masking_color = '#beefed',
                custom_masking_opacity = 40,
                mfa_enrollment_message = 'You must register with the OneLogin Protect app in order to login',
                enable_custom_label_for_login_screen = True,
                custom_label_text_for_login_screen = 'ACME Username or Email',
                login_instruction = 'To login, enter your ACME Username or Email. Reach out to help.desk@acme.org if you have trouble logging in.',
                login_instruction_title = 'ACME Login Instructions',
                hide_onelogin_footer = True,
                background = onelogin.models.create_brand_201_response_background.createBrand_201_response_background(
                    urls = onelogin.models.create_brand_201_response_background_urls.createBrand_201_response_background_urls(
                        original = '', 
                        login = '', 
                        branding = '', ), 
                    file_size = 56, 
                    updated_at = '', 
                    content_type = '', ),
                logo = onelogin.models.create_brand_201_response_logo.createBrand_201_response_logo(
                    urls = onelogin.models.create_brand_201_response_logo_urls.createBrand_201_response_logo_urls(
                        original = '', 
                        login = '', 
                        navigation = '', ), 
                    file_size = 56, 
                    updated_at = '', 
                    content_type = '', ),
        )
        """

    def testCreateBrand201Response(self):
        """Test CreateBrand201Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, validator
from onelogin.models.list_apps200_response_provisioning import ListApps200ResponseProvisioning

class ListApps200Response(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    id: Optional[StrictInt] = Field(None, description="Apps unique ID in OneLogin.")
    connector_id: Optional[StrictInt] = Field(None, description="ID of the apps underlying connector.")
    name: Optional[StrictStr] = Field(None, description="App name.")
    description: Optional[StrictStr] = Field(None, description="Freeform description of the app.")
    notes: Optional[StrictStr] = Field(None, description="Freeform notes about the app.")
    policy_id: Optional[StrictInt] = Field(None, description="The security policy assigned to the app.")
    brand_id: Optional[StrictInt] = Field(None, description="The custom login page branding to use for this app. Applies to app initiated logins via OIDC or SAML.")
    icon_url: Optional[StrictStr] = Field(None, description="A link to the apps icon url.")
    visible: Optional[StrictBool] = Field(None, description="Indicates if the app is visible in the OneLogin portal.")
    auth_method: Optional[StrictInt] = Field(None, description="An ID indicating the type of app.")
    tab_id: Optional[StrictInt] = Field(None, description="ID of the OneLogin portal tab that the app is assigned to.")
    created_at: Optional[StrictStr] = Field(None, description="The date the app was created.")
    updated_at: Optional[StrictStr] = Field(None, description="The date the app was last updated.")
    role_ids: Optional[List[StrictInt]] = Field(None, description="A list of OneLogin Role IDs of the user")
    allow_assumed_signin: Optional[StrictBool] = Field(None, description="Indicates whether or not administrators can access the app as a user that they have assumed control over.")
    provisioning: Optional[ListApps200ResponseProvisioning] = None
    __properties = ["id", "connector_id", "name", "description", "notes", "policy_id", "brand_id", "icon_url", "visible", "auth_method", "tab_id", "created_at", "updated_at", "role_ids", "allow_assumed_signin", "provisioning"]

    @validator('auth_method')
    def auth_method_validate_enum(cls, v):
        if v is None:
            return v

        if v not in (0, 1, 2, 3, 4, 6, 7, 8):
            raise ValueError("must validate the enum values (0, 1, 2, 3, 4, 6, 7, 8)")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ListApps200Response:
        """Create an instance of ListApps200Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of provisioning
        if self.provisioning:
            _dict['provisioning'] = self.provisioning.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ListApps200Response:
        """Create an instance of ListApps200Response from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ListApps200Response.parse_obj(obj)

        _obj = ListApps200Response.parse_obj({
            "id": obj.get("id"),
            "connector_id": obj.get("connector_id"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "notes": obj.get("notes"),
            "policy_id": obj.get("policy_id"),
            "brand_id": obj.get("brand_id"),
            "icon_url": obj.get("icon_url"),
            "visible": obj.get("visible"),
            "auth_method": obj.get("auth_method"),
            "tab_id": obj.get("tab_id"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "role_ids": obj.get("role_ids"),
            "allow_assumed_signin": obj.get("allow_assumed_signin"),
            "provisioning": ListApps200ResponseProvisioning.from_dict(obj.get("provisioning")) if obj.get("provisioning") is not None else None
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr

class CreateFactorRegistration201Response(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    device_id: Optional[StrictStr] = Field(None, description="MFA device identifier.")
    user_display_name: Optional[StrictStr] = Field(None, description="Authentication factor display name assigned by users when they register the device.")
    type_display_name: Optional[StrictStr] = Field(None, description="Authentication factor display name as it appears to users upon initial registration, as defined by admins at Settings > Authentication Factors.")
    auth_factor_name: Optional[StrictStr] = Field(None, description="Authentication factor name, as it appears to administrators in OneLogin.")
    id: Optional[StrictStr] = Field(None, description="Verification identifier used in subsequent verification step.")
    user_id: Optional[StrictStr] = Field(None, description="User identifier")
    __properties = ["device_id", "user_display_name", "type_display_name", "auth_factor_name", "id", "user_id"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CreateFactorRegistration201Response:
        """Create an instance of CreateFactorRegistration201Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CreateFactorRegistration201Response:
        """Create an instance of CreateFactorRegistration201Response from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CreateFactorRegistration201Response.parse_obj(obj)

        _obj = CreateFactorRegistration201Response.parse_obj({
            "device_id": obj.get("device_id"),
            "user_display_name": obj.get("user_display_name"),
            "type_display_name": obj.get("type_display_name"),
            "auth_factor_name": obj.get("auth_factor_name"),
            "id": obj.get("id"),
            "user_id": obj.get("user_id")
        })
        return _obj




# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.get_role_by_name200_response import GetRoleByName200Response  # noqa: E501
from onelogin.rest import ApiException

class TestGetRoleByName200Response(unittest.TestCase):
    """GetRoleByName200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GetRoleByName200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetRoleByName200Response`
        """
        model = onelogin.models.get_role_by_name200_response.GetRoleByName200Response()  # noqa: E501
        if include_optional :
            return GetRoleByName200Response(
                status = onelogin.models.generate_token_400_response.generateToken_400_response(
                    error = False, 
                    code = 200, 
                    type = 'Success', 
                    message = 'Success', ), 
                pagination = onelogin.models.get_role_by_name_200_response_pagination.getRoleByName_200_response_pagination(
                    after_cursor = 'xWNjb3VudF9pZDo6OjUzNDEzLS0jI2lkOjo6OTA0MjU3NTQ2', 
                    before_cursor = '""', 
                    next_link = 'https://{subdomain}.onelogin.com/api/1/events?after_cursor=xWNjb3VudF9pZDo6OjUzNDEzLS0jI2lkOjo6OTA0MjU3NTQ2', 
                    previous_link = '""', ), 
                data = [{"id":1111,"name":"C-Executive"},{"id":1112,"name":"Contractor"},{"id":1113,"name":"Default"},{"id":1114,"name":"Employee"}]
            )
        else :
            return GetRoleByName200Response(
        )
        """

    def testGetRoleByName200Response(self):
        """Test GetRoleByName200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.get_invite_link200_response import GetInviteLink200Response  # noqa: E501
from onelogin.rest import ApiException

class TestGetInviteLink200Response(unittest.TestCase):
    """GetInviteLink200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GetInviteLink200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetInviteLink200Response`
        """
        model = onelogin.models.get_invite_link200_response.GetInviteLink200Response()  # noqa: E501
        if include_optional :
            return GetInviteLink200Response(
                status = onelogin.models.generate_token_400_response.generateToken_400_response(
                    error = False, 
                    code = 200, 
                    type = 'Success', 
                    message = 'Success', ), 
                data = [
                    ''
                    ]
            )
        else :
            return GetInviteLink200Response(
        )
        """

    def testGetInviteLink200Response(self):
        """Test GetInviteLink200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onelogin
from onelogin.models.list_apps200_response import ListApps200Response  # noqa: E501
from onelogin.rest import ApiException

class TestListApps200Response(unittest.TestCase):
    """ListApps200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListApps200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListApps200Response`
        """
        model = onelogin.models.list_apps200_response.ListApps200Response()  # noqa: E501
        if include_optional :
            return ListApps200Response(
                id = 1061937, 
                connector_id = 50534, 
                name = 'Amazon Web Services Multi-Role', 
                description = 'Whatever you  like', 
                notes = '', 
                policy_id = 56, 
                brand_id = 56, 
                icon_url = '', 
                visible = True, 
                auth_method = 2, 
                tab_id = 56, 
                created_at = '2020-01-14T21:21:06.000Z', 
                updated_at = '2020-01-14T21:21:06.000Z', 
                role_ids = [
                    56
                    ], 
                allow_assumed_signin = True, 
                provisioning = onelogin.models.list_apps_200_response_provisioning.listApps_200_response_provisioning(
                    enabled = True, )
            )
        else :
            return ListApps200Response(
        )
        """

    def testListApps200Response(self):
        """Test ListApps200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
